@@ -27,5 +27,5 @@ class BartApi():
     url = "http://api.bart.gov/api/stn.aspx?cmd=stns&key=%s" % (self.api_key)
     raw_response = urllib.request.urlopen(url)
     xml = self.parse_response(raw_response)
-    et = etree.ElementTree(xml) 
-    et.write('output.xml', pretty_print=True, xml_declaration=True)
+    with open('station_list.xml', 'w') as f:
+      f.write(etree.tostring(xml))
